@@ -1,4 +1,3 @@
-#!/usr/bin/python
 ##
 ## Generic SecurePass Class to access APIs of Dreamliner
 ## www.secure-pass.net
@@ -102,7 +101,7 @@ class SecurePass(object):
           # Send request and wait for response
           try:
             curl.perform()
-          except pycurl.error, err:
+          except pycurl.error as err:
             if err.args[0] in _CURL_SSL_CERT_ERRORS:
               self._logger.error("SSL certificate error %s" % err,
                                   code=err.args[0])
@@ -640,6 +639,84 @@ class SecurePass(object):
         else:
             raise Exception(response['errorMsg'])
 
+
+    ##
+    ## SecurePass Realms extended attributes (xattr)
+    ##
+
+    def realms_xattr_list(self, realm=None):
+        """ Get Users' extended attributes
+        """
+
+        request = {}
+
+        if realm is not None:
+            request['REALM'] = realm
+
+        response = self._SendRequest(HTTP_POST, "/api/v1/realms/xattrs/list", content=request)
+
+        if response['rc'] == 0:
+            del response['rc']
+            del response['errorMsg']
+
+            return response
+
+        else:
+            raise Exception(response['errorMsg'])
+
+
+    def realms_xattr_set(self, realm=None, attribute=None, value=None):
+        """ Set Users' extended attributes
+        """
+
+        request = {}
+
+        if realm is not None:
+            request['REALM'] = realm
+
+        if attribute is not None:
+            request['ATTRIBUTE'] = attribute
+
+        if value is not None:
+            request['VALUE'] = value
+
+        response = self._SendRequest(HTTP_POST, "/api/v1/realms/xattrs/set", content=request)
+
+        if response['rc'] == 0:
+            del response['rc']
+            del response['errorMsg']
+
+            return response
+
+        else:
+            raise Exception(response['errorMsg'])
+
+
+    def realms_xattr_delete(self, realm=None, attribute=None):
+        """ Delete  Users' extended attribute
+        """
+
+        request = {}
+
+        if realm is not None:
+            request['REALM'] = realm
+
+        if attribute is not None:
+            request['ATTRIBUTE'] = attribute
+
+        response = self._SendRequest(HTTP_POST, "/api/v1/realms/xattrs/delete", content=request)
+
+        if response['rc'] == 0:
+            del response['rc']
+            del response['errorMsg']
+
+            return response
+
+        else:
+            raise Exception(response['errorMsg'])
+
+
+
     ##
     ## SecurePass Group handling
     ##
@@ -884,4 +961,4 @@ class SecurePass(object):
             return response
 
         else:
-            raise Exception(response['errorMsg'])
\ No newline at end of file
+            raise Exception(response['errorMsg'])
